bench : Benchmark whisper.cpp performance in the browser
You can find more about this project on GitHub.

Select the model you would like to use and click the "Bench" button.
The results will be displayed in the textarea below.
Whisper model:

Debug output:
Troubleshooting
The page does some heavy computations, so make sure:

- To use a modern web browser (e.g. Chrome, Firefox)
- To use a fast desktop or laptop computer (i.e. not a mobile phone)
- Your browser supports WASM Fixed-width SIMD

| Build time: @GIT_DATE@ | Commit hash: @GIT_SHA1@ | Commit subject: @GIT_COMMIT_SUBJECT@ | Source Code |